pub struct Header {
pub name_start: usize,
pub name_end: usize,
pub value_start: usize,
pub value_end: usize,
}Expand description
Represents a parsed header.
Fields
name_start: usizeThe name portion of a header.
A header name must be valid ASCII-US, so it’s safe to store as a &str.
name_end: usizevalue_start: usizeThe value portion of a header.
While headers should be ASCII-US, the specification allows for values that may not be, and so the value is stored as bytes.
value_end: usizeTrait Implementations
impl Copy for Header
impl Eq for Header
impl StructuralPartialEq for Header